# change the MD5 [![The MIT License](https://img.shields.io/badge/license-MIT-green.svg?style=flat-square)](http://opensource.org/licenses/MIT) [![PyPI](https://img.shields.io/pypi/v/md5ct.svg?style=flat-square)](https://pypi.org/project/md5ct/)

可以批量修改文件或者文件夹下文件的md5

文件名转换为拼音

## 安装
``` shell
$ pip3 install md5ct
```

## 使用
``` shell
$ ctmd5 -[你的路径] -py(可选，是否将文件名转为拼音) -rv(可选，是否将文件反转)
```

## LICENSE

The MIT License [@ixiongyu](https://github.com/ixiongyu)



## 感谢 JetBrains 免费的开源授权

<a href="https://www.jetbrains.com/?from=https://github.com/ixiongyu/notes" target="_blank">
<img src="https://github.com/ixiongyu/notes/raw/master/imgs/jetbrains.png" height="200" alt="jetbrains_logo"/></a>


## 作者信息


作者博客：https://blog.csdn.net/

作者邮箱： ixiongyu@gmail.com
